commit 12557b094ce1a6376cf77003a443592af235f2a7
Author: Kornel Benko <kor...@lyx.org>
Date:   Sat Oct 24 14:05:19 2020 +0200

    Checking po-files (shortcut handling)
    
    1.) Allow ' ' as a menu shortcut (corrected for missing/unexpected spaces 
at message end)
    2.) Adapt for utf-8 shortcuts (corrected chacking for missing/unexpected 
shortcuts)
---
 po/pocheck.pl |   19 +++++++++++++++----
 1 files changed, 15 insertions(+), 4 deletions(-)

diff --git a/po/pocheck.pl b/po/pocheck.pl
index 391245a..db59aa0 100755
--- a/po/pocheck.pl
+++ b/po/pocheck.pl
@@ -168,8 +168,11 @@ foreach my $pofilename ( @ARGV ) {
     }
 
     if ($check_spaces) {
-      # Check space at the end of a message
-      if ( ( $msgid =~ m/  *?(\|.*)?$/ ) != ( $msgstr =~ m/  *?(\|.*)?$/ ) ) {
+      # Check space at the end of a message (if not a shortcut)
+      my ($msgid1, $msgstr1);
+      ($msgid1 = $msgid) =~ s/\|.$//;
+      ($msgstr1 = $msgstr) =~ s/\|.$//;        # TODO: Shortcut may be utf-8 
char
+      if (($msgid1 =~ / $/) != ($msgstr1 =~ / $/)) {
         print "Line $linenum: Missing or unexpected space:\n  '$msgid' => 
'$msgstr'\n"
           unless $only_total;
         ++$bad{"Bad spaces"};
@@ -188,8 +191,16 @@ foreach my $pofilename ( @ARGV ) {
     }
 
     if ($check_menu) {
-      # Check for "|..." shortcuts
-      if ( ( $msgid =~ m/\|[^ ]/ ) != ( $msgstr =~ m/\|[^ ]/ ) ) {
+      # Check for "|..." shortcuts (space shortcut allowed)
+      # Shortcut is either 1 char (ascii in msgid) or utf8 char (in msgstr)
+      my ($s1, $s2) = (0,0);
+      $s1 = 1 if ($msgid =~ /\|([^\|])$/);
+      if ($msgstr =~ /\|([^\|]+)$/) {
+       my $chars = $1;
+       my $u = decode('utf-8', $chars);
+       $s2 = 1 if (length($u) == 1);
+      }
+      if($s1 != $s2) {
         print "Line $linenum: Missing or unexpected menu shortcut:\n  '$msgid' 
=> '$msgstr'\n"
           unless $only_total;
         ++$bad{"Bad menu shortcuts"};
-- 
lyx-cvs mailing list
lyx-cvs@lists.lyx.org
http://lists.lyx.org/mailman/listinfo/lyx-cvs

Reply via email to